@@ -24,15 +24,15 @@ import json
 from collections.abc import Sequence
 from typing import TYPE_CHECKING, Any
 
-from googleapiclient.errors import HttpError
-
-from airflow.exceptions import AirflowException
-from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 from google.api_core.exceptions import InvalidArgument
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.cloud import monitoring_v3
 from google.cloud.monitoring_v3 import AlertPolicy, NotificationChannel
 from google.protobuf.field_mask_pb2 import FieldMask
+from googleapiclient.errors import HttpError
+
+from airflow.providers.common.compat.sdk import AirflowException
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
 if TYPE_CHECKING:
     from google.api_core.retry import Retry
@@ -121,10 +121,9 @@ class StackdriverHook(GoogleBaseHook):
         )
         if format_ == "dict":
             return [AlertPolicy.to_dict(policy) for policy in policies_]
-        elif format_ == "json":
+        if format_ == "json":
             return [AlertPolicy.to_jsoon(policy) for policy in policies_]
-        else:
-            return policies_
+        return policies_
 
     @GoogleBaseHook.fallback_to_default_project_id
     def _toggle_policy_status(
@@ -262,8 +261,9 @@ class StackdriverHook(GoogleBaseHook):
         channel_name_map = {}
 
         for channel in channels:
+            # This field is immutable, illegal to specifying non-default UNVERIFIED or VERIFIED, so setting default
             channel.verification_status = (
-                monitoring_v3.NotificationChannel.VerificationStatus.VERIFICATION_STATUS_UNSPECIFIED
+                monitoring_v3.NotificationChannel.VerificationStatus.VERIFICATION_STATUS_UNSPECIFIED  # type: ignore[assignment]
             )
 
             if channel.name in existing_channels:
@@ -275,7 +275,7 @@ class StackdriverHook(GoogleBaseHook):
                 )
             else:
                 old_name = channel.name
-                channel.name = None
+                del channel.name
                 new_channel = channel_client.create_notification_channel(
                     request={"name": f"projects/{project_id}", "notification_channel": channel},
                     retry=retry,
@@ -285,8 +285,8 @@ class StackdriverHook(GoogleBaseHook):
                 channel_name_map[old_name] = new_channel.name
 
         for policy in policies_:
-            policy.creation_record = None
-            policy.mutation_record = None
+            del policy.creation_record
+            del policy.mutation_record
 
             for i, channel in enumerate(policy.notification_channels):
                 new_channel = channel_name_map.get(channel)
@@ -302,9 +302,9 @@ class StackdriverHook(GoogleBaseHook):
                         metadata=metadata,
                     )
             else:
-                policy.name = None
+                del policy.name
                 for condition in policy.conditions:
-                    condition.name = None
+                    del condition.name
                 policy_client.create_alert_policy(
                     request={"name": f"projects/{project_id}", "alert_policy": policy},
                     retry=retry,
@@ -395,10 +395,9 @@ class StackdriverHook(GoogleBaseHook):
         )
         if format_ == "dict":
             return [NotificationChannel.to_dict(channel) for channel in channels]
-        elif format_ == "json":
+        if format_ == "json":
             return [NotificationChannel.to_json(channel) for channel in channels]
-        else:
-            return channels
+        return channels
 
     @GoogleBaseHook.fallback_to_default_project_id
     def _toggle_channel_status(
@@ -533,8 +532,9 @@ class StackdriverHook(GoogleBaseHook):
             channels_list.append(NotificationChannel(**channel))
 
         for channel in channels_list:
+            # This field is immutable, illegal to specifying non-default UNVERIFIED or VERIFIED, so setting default
             channel.verification_status = (
-                monitoring_v3.NotificationChannel.VerificationStatus.VERIFICATION_STATUS_UNSPECIFIED
+                monitoring_v3.NotificationChannel.VerificationStatus.VERIFICATION_STATUS_UNSPECIFIED  # type: ignore[assignment]
             )
 
             if channel.name in existing_channels:
@@ -546,7 +546,7 @@ class StackdriverHook(GoogleBaseHook):
                 )
             else:
                 old_name = channel.name
-                channel.name = None
+                del channel.name
                 new_channel = channel_client.create_notification_channel(
                     request={"name": f"projects/{project_id}", "notification_channel": channel},
                     retry=retry,
