@@ -51,10 +51,15 @@ from airflow.providers.google.cloud.operators.cloud_sql import (
     CloudSQLDeleteInstanceOperator,
     CloudSQLExecuteQueryOperator,
 )
-from airflow.utils.trigger_rule import TriggerRule
+
+try:
+    from airflow.sdk import TriggerRule
+except ImportError:
+    # Compatibility for Airflow < 3.1
+    from airflow.utils.trigger_rule import TriggerRule  # type: ignore[no-redef,attr-defined]
 
 from system.google import DEFAULT_GCP_SYSTEM_TEST_PROJECT_ID
-from tests_common.test_utils.api_client_helpers import create_airflow_connection, delete_airflow_connection
+from system.google.gcp_api_client_helpers import create_airflow_connection, delete_airflow_connection
 
 ENV_ID = os.environ.get("SYSTEM_TESTS_ENV_ID", "default")
 PROJECT_ID = os.environ.get("SYSTEM_TESTS_GCP_PROJECT") or DEFAULT_GCP_SYSTEM_TEST_PROJECT_ID
@@ -336,6 +341,7 @@ with DAG(
             create_airflow_connection(
                 connection_id=connection_id,
                 connection_conf=connection,
+                is_composer=run_in_composer(),
             )
             return connection_id
 
@@ -456,7 +462,7 @@ with DAG(
 
         @task(task_id=f"delete_connection_{database_type}")
         def delete_connection(connection_id: str) -> None:
-            delete_airflow_connection(connection_id=connection_id)
+            delete_airflow_connection(connection_id=connection_id, is_composer=run_in_composer())
 
         delete_connection_task = delete_connection(connection_id=conn_id)
 
